## History

#### 1.4.1

- Small fixes for some redefinition errors, and mispelled macros.
- Slightly rearrangement of structure to comply with current library requirements.

#### 1.4

- Add detection of SIMD hardware. With the addition of the `BOOST_HW_*` category (from Charly Chevalier).
- Add compile only version of check utilities to address cross-compile use cases. And changed the BBv2 check support to use compile only checks.
- Fix test warnings.
- Fix typos on `AVAILABLE` macros for Windows Platform. (from Vemund Handeland)

#### 1.3

- Fix many problems with `predef_check` functionality.
- Update SunPro detection to accomodate latest version of compiler from Oracle.
- Addition of Travis-CI and Appveyor testing.
- Add `and` and `or` logical operators for `predef_check` expression on the Boost Build side.
- Fix `BOOST_ARCH_PARISC` to correctly spelled name (from Graham Hanson).
- Fix `MAKE_YYYYM` macros to correctly limit the month (from rick68).

#### 1.2

- Account for skip in Visual Studio product version vs. compiler version. This supports version of VS 2015 an onward.
- Add detection of Haiku OS (from Jessica Hamilton).
- Some fixes to endian detection for Android (from mstahl-at-redhat.com).
- Add missing `BOOST_PREDEF_MAKE_0X_VVRRPP` macro (from Erik Lindahl).
- Add `predef_check` program and BBv2 integration for build configuration checks.

#### 1.1

- Addition of `BOOST_PLAT_*` platform definitions for MinGW and Windows platform variants.
- Detection of ARM architecture for Windows compilers to target mobile devices of Windows 8.
- Improved ARM detection for 64 bit ARM.
- Added detection of iOS an an operating system.
- Improved detection of endianess on some platforms.
- Addition of exclusive plus emulated definitions for platform and compiler detection.

| Warning
The big change for this version is the restructuring of the definitions to avoid duplicate definitions in one category. That is, only one `BOOST_OS_*`, `BOOST_COMP_*`, and `BOOST_PLAT_*` variant will be detected (except for sub-categories).